# Process Steps

A process step is the running instance of a step with all its relevant information. When a workflow is started a process step is created for every step that gets executed. Therefore, all fields are read-only.

## Columns:
Each column title has three lines on the right if you hover over it. Click on them to show options for that column. The second tab of the options menu will allow you to filter the column, the third to completely hide entire columns. Click on anywhere else on the column to order it, cycling between ascending, descending and no ordering. Hold shift while clicking to order multiple columns with individual weights.

### UUID:
Unique identifier for this process step.

### Step:
The step that is currently being executed.

### Process:
The process that this process step belongs to.

### Workflow:
The workflow that is currently being executed.

### Started:
Date and time at which this step was started.

### Finished:
Date and time at which this step was finished.

### Error Message:
The error message in case this step failed.

### Assignee:
The person that this process step is assigned to.

### Group:
The group that this process step is assigned to.

### Permission:
The permission that is needed to be able to view this item.

### Status:
The status that was set on the attached model when this step was executed.

## Legend:
Click on a state in the legend to filter the list.

## Filters:
Filters are accessed by clicking on the symbol in the top left corner of the window.

### States:
Filter processes by a specific state they're in, smiliarly to what clicking on the legend does.

## Search Field:
Typing in the search field allows to filter the by workflow or step name.
